;; Generated package description from marginalia.el  -*- no-byte-compile: t -*-
(define-package "marginalia" "1.3" "Enrich existing commands with completion annotations" '((emacs "27.1") (compat "29.1.4.0")) :commit "8cffd7dcdb411f8796258183a4224653d407ae3f" :authors '(("Omar Antolín Camarena <omar@matem.unam.mx>, Daniel Mendler" . "mail@daniel-mendler.de")) :maintainer '("Omar Antolín Camarena <omar@matem.unam.mx>, Daniel Mendler" . "mail@daniel-mendler.de") :keywords '("docs" "help" "matching" "completion") :url "https://github.com/minad/marginalia")
